@@ -2,16 +2,11 @@
 #
 # Encodings of Arabic ##########################################################################
 
+# $Id: Arabic.pm 143 2006-11-15 01:16:57Z smrz $
+
 package Encode::Arabic;
 
-use 5.008;
-
-use strict;
-use warnings;
-
-use Carp;
-
-our $VERSION = '1.9.1';
+our $VERSION = '1.24' || do { q $Revision: 143 $ =~ /(\d+)/; sprintf "%4.2f", $1 / 100 };
 
 
 sub import {            # perform import as if Encode were used one level before this module
@@ -20,8 +15,8 @@ sub import {            # perform import as if Encode were used one level before
 
         require Exporter;
 
-        our @ISA = qw 'Exporter';
-        our @EXPORT_OK = qw 'enmode demode';
+        @ISA = qw 'Exporter';
+        @EXPORT_OK = qw 'enmode demode';
 
         __PACKAGE__->export_to_level(1, $_[0], 'enmode', 'demode');
 
@@ -30,8 +25,6 @@ sub import {            # perform import as if Encode were used one level before
 
     require Encode;
 
-    push @Encode::ISA, 'Exporter' unless Encode->can('export_to_level');
-
     Encode->export_to_level(1, @_);
 }
 
@@ -50,15 +43,17 @@ use Encode::Arabic::Buckwalter;
 
 use Encode::Arabic::Parkinson;
 
-use Encode::Arabic::Habash;
-
 
 sub enmode ($@) {
 
     my $enc = shift;
     my $obj = Encode::find_encoding($enc);
 
-    croak "Unknown encoding '$enc'" unless defined $obj;
+    unless (defined $obj){
+
+        require Carp;
+        Carp::croak("Unknown encoding '$enc'");
+    }
 
     $obj->enmode(@_);
 }
@@ -69,7 +64,11 @@ sub demode ($@) {
     my $enc = shift;
     my $obj = Encode::find_encoding($enc);
 
-    croak "Unknown encoding '$enc'" unless defined $obj;
+    unless (defined $obj){
+
+        require Carp;
+        Carp::croak("Unknown encoding '$enc'");
+    }
 
     $obj->demode(@_);
 }
@@ -85,6 +84,11 @@ __END__
 Encode::Arabic - Encodings of Arabic
 
 
+=head1 REVISION
+
+    $Revision: 143 $        $Date: 2006-11-15 02:16:57 +0100 (Wed, 15 Nov 2006) $
+
+
 =head1 SYNOPSIS
 
     use Encode::Arabic;                 # imports just like 'use Encode' even with options would
@@ -179,12 +183,6 @@ Parkinson one-to-one notation for Arabic / Perl's internal format for the Arabic
 
 L<Encode::Arabic::Parkinson|Encode::Arabic::Parkinson>
 
-=item Habash
-
-Habash-Soudi-Buckwalter one-to-one notation for Arabic / Perl's internal format for the Arabic script
-
-L<Encode::Arabic::Habash|Encode::Arabic::Habash>
-
 =back
 
 There are generic aliases to these provided by L<Encode|Encode>. Case does not matter and all
@@ -221,14 +219,18 @@ of the listed encodings.
 
 =head1 SEE ALSO
 
-Encode::Arabic Online Interface L<http://encode-arabic.sourceforge.net/>
+Encode::Arabic Online Interface L<http://ufal.mff.cuni.cz/~smrz/Encode/Arabic/>
+
+Klaus Lagally's ArabTeX         L<ftp://ftp.informatik.uni-stuttgart.de/pub/arabtex/arabtex.htm>
+
+Tim Buckwalter's Qamus          L<http://www.qamus.org/>
+
+Arabeyes Arabic Unix Project    L<http://www.arabeyes.org/>
+
+Lecture Notes on Arabic NLP     L<http://ufal.mff.cuni.cz/~smrz/ANLP/anlp-lecture-notes.pdf>
 
 Encode Arabic Project           L<http://sourceforge.net/projects/encode-arabic/>
 
-ElixirFM Online Interface       L<http://elixir-fm.sourceforge.net/>
-
-ElixirFM Project                L<http://sourceforge.net/projects/elixir-fm/>
-
 L<Encode|Encode>,
 L<Encode::Encoding|Encode::Encoding>,
 L<Encode::Mapper|Encode::Mapper>,
@@ -246,12 +248,16 @@ L<Text::TransMetaphone|Text::TransMetaphone>
 
 =head1 AUTHOR
 
-Otakar Smrz C<< <otakar-smrz users.sf.net> >>, L<http://otakar-smrz.users.sf.net/>
+Otakar Smrz, L<http://ufal.mff.cuni.cz/~smrz/>
+
+    eval { 'E<lt>' . ( join '.', qw 'otakar smrz' ) . "\x40" . ( join '.', qw 'mff cuni cz' ) . 'E<gt>' }
+
+Perl is also designed to make the easy jobs not that easy ;)
 
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2003-2014 Otakar Smrz
+Copyright 2003-2006 by Otakar Smrz
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
