@@ -2,6 +2,8 @@
 #
 # Encoding of Arabic: ArabTeX Notation by Klaus Lagally, ZDMG #################################
 
+# $Id: ZDMG.pm 143 2006-11-15 01:16:57Z smrz $
+
 package Encode::Arabic::ArabTeX::ZDMG;
 
 use 5.008;
@@ -11,6 +13,9 @@ use warnings;
 
 use Carp;
 
+our $VERSION = do { q $Revision: 143 $ =~ /(\d+)/; sprintf "%4.2f", $1 / 100 };
+
+
 use Encode::Arabic::ArabTeX ();
 use base 'Encode::Arabic::ArabTeX';
 
@@ -74,9 +79,7 @@ sub import {            # perform import as if Encode were used one level before
 
     require Encode;
 
-    push @Encode::ISA, 'Exporter' unless Encode->can('export_to_level');
-
-    Encode->export_to_level(1, @_);
+    Encode->export_to_level(1, @_);     # here comes the only trick ^^
 }
 
 
@@ -258,7 +261,7 @@ sub decoder ($;$$) {
                     [   "T",        "\x{0074}"          ],
                     [   "H",        "\x{0068}"          ],  #   ""
                     [   "N",        "\x{006E}"          ],
-                    [   "W",        "\x{0077}"          ],  #   ""
+                    [   "W",        ""                  ],  #   "\x{0077}"
                 );
 
 
@@ -271,7 +274,6 @@ sub decoder ($;$$) {
                     [   "_aI",      "\x{0061}\x{0304}"  ],  #   "\x{0101}"
                     [   "A",        "\x{0061}\x{0304}"  ],  #   "\x{0101}"
                     [   "^A",       "\x{0061}\x{0304}"  ],  #   "\x{0101}"
-                    [   "_A",       "\x{0061}\x{0304}"  ],  #   "\x{0101}"
                     [   "e",        "\x{0065}"          ],
                     [   "E",        "\x{0065}\x{0304}"  ],  #   "\x{0113}"
                     [   "i",        "\x{0069}"          ],
@@ -296,13 +298,6 @@ sub decoder ($;$$) {
                 );
 
 
-    my @empty = (
-                    [   "\"",       "",                 ],  #   "\x{02BC}"
-                    [   "|",        "",                 ],
-                    [   "B",        "",                 ],
-                );
-
-
     my @moony = (
                     [   "b",        "\x{0062}"          ],
                     [   "^g",       "\x{0067}\x{030C}"  ],  #   "\x{01E7}"
@@ -337,11 +332,15 @@ sub decoder ($;$$) {
                     'silent' => 0,
                 ],
 
+                    "\"",               "\x{02BC}",
+                    "|",                "",
+                    "B",                "",
+
                 # definite article assimilation .. non-linguistic
                 (
                     map {
 
-                        "l-" . $_->[0] x 2, [ "", $_->[0] . "-" . $_->[0] ],
+                        "l-" . $_->[0] x 2, [ '', $_->[0] . "-" . $_->[0] ],
 
                     } @sunny, @moony
                 ),
@@ -375,13 +374,8 @@ sub decoder ($;$$) {
 
                 # silence the silent
 
-                    "_W",           "",
-
                     "WA",           [ "", "W" ],
-
-                    "UW",           [ "", "U" ],
                     "UA",           [ "", "U" ],
-
                     "NA",           [ "", "N" ],
                     "NY",           [ "", "N" ],
                     "NU",           [ "", "N" ],
@@ -398,90 +392,7 @@ sub decoder ($;$$) {
                         "\\cap\x0D" . $_->[0], ucfirst $_->[1],
                         "\\cap\x20" . $_->[0], ucfirst $_->[1],
 
-                    } @sunny, @moony, @empty, @vowel, @extra
-                ),
-
-                (
-                    map {
-
-                        $_->[0] . "i", $_->[1] . "i",
-                        $_->[0] . "u", $_->[1] . "u",
-
-                        "\\cap\x09" . $_->[0] . "i", ucfirst $_->[1] . "i",
-                        "\\cap\x0A" . $_->[0] . "i", ucfirst $_->[1] . "i",
-                        "\\cap\x0D" . $_->[0] . "i", ucfirst $_->[1] . "i",
-                        "\\cap\x20" . $_->[0] . "i", ucfirst $_->[1] . "i",
-
-                        "\\cap\x09" . $_->[0] . "u", ucfirst $_->[1] . "u",
-                        "\\cap\x0A" . $_->[0] . "u", ucfirst $_->[1] . "u",
-                        "\\cap\x0D" . $_->[0] . "u", ucfirst $_->[1] . "u",
-                        "\\cap\x20" . $_->[0] . "u", ucfirst $_->[1] . "u",
-
-                    } @sunny, @moony, @empty
-                ),
-
-                (
-                    map {
-
-                        my $x = $_;
-
-                        map {
-
-                            $x->[0] . "i" . $_, [ $x->[1], "i" . $_ ],
-                            $x->[0] . "u" . $_, [ $x->[1], "u" . $_ ],
-
-                            "\\cap\x09" . $x->[0] . "i" . $_, [ ucfirst $x->[1], "i" . $_ ],
-                            "\\cap\x0A" . $x->[0] . "i" . $_, [ ucfirst $x->[1], "i" . $_ ],
-                            "\\cap\x0D" . $x->[0] . "i" . $_, [ ucfirst $x->[1], "i" . $_ ],
-                            "\\cap\x20" . $x->[0] . "i" . $_, [ ucfirst $x->[1], "i" . $_ ],
-
-                            "\\cap\x09" . $x->[0] . "u" . $_, [ ucfirst $x->[1], "u" . $_ ],
-                            "\\cap\x0A" . $x->[0] . "u" . $_, [ ucfirst $x->[1], "u" . $_ ],
-                            "\\cap\x0D" . $x->[0] . "u" . $_, [ ucfirst $x->[1], "u" . $_ ],
-                            "\\cap\x20" . $x->[0] . "u" . $_, [ ucfirst $x->[1], "u" . $_ ],
-
-                        }   "-", "\x09", "\x0A", "\x0D", "\x20"
-
-                    } @sunny, @moony, @empty
-                ),
-
-                # initial vowel assimilation
-                (
-                    map {
-
-                        my $fix = $_;
-
-                        "i" . $_, [ "", "I" ],
-                        "u" . $_, [ "", "U" ],
-
-                        "\\cap\x09" . "i" . $_, [ "", "\\cap\x09" . "I" ],
-                        "\\cap\x0A" . "i" . $_, [ "", "\\cap\x0A" . "I" ],
-                        "\\cap\x0D" . "i" . $_, [ "", "\\cap\x0D" . "I" ],
-                        "\\cap\x20" . "i" . $_, [ "", "\\cap\x20" . "I" ],
-
-                        "\\cap\x09" . "u" . $_, [ "", "\\cap\x09" . "U" ],
-                        "\\cap\x0A" . "u" . $_, [ "", "\\cap\x0A" . "U" ],
-                        "\\cap\x0D" . "u" . $_, [ "", "\\cap\x0D" . "U" ],
-                        "\\cap\x20" . "u" . $_, [ "", "\\cap\x20" . "U" ],
-
-                        map {
-
-                            "i" . $fix . $_->[0], [ "i", $fix . $_->[0] ],
-                            "u" . $fix . $_->[0], [ "u", $fix . $_->[0] ],
-
-                            "\\cap\x09" . "i" . $fix . $_->[0], [ "I", $fix . $_->[0] ],
-                            "\\cap\x0A" . "i" . $fix . $_->[0], [ "I", $fix . $_->[0] ],
-                            "\\cap\x0D" . "i" . $fix . $_->[0], [ "I", $fix . $_->[0] ],
-                            "\\cap\x20" . "i" . $fix . $_->[0], [ "I", $fix . $_->[0] ],
-
-                            "\\cap\x09" . "u" . $fix . $_->[0], [ "U", $fix . $_->[0] ],
-                            "\\cap\x0A" . "u" . $fix . $_->[0], [ "U", $fix . $_->[0] ],
-                            "\\cap\x0D" . "u" . $fix . $_->[0], [ "U", $fix . $_->[0] ],
-                            "\\cap\x20" . "u" . $fix . $_->[0], [ "U", $fix . $_->[0] ],
-
-                        } @vowel, $empty[0]
-
-                    } "y", "w"  # "'"
+                    } @sunny, @moony, @vowel, @extra
                 ),
 
                 # capitalization of minors
@@ -490,49 +401,11 @@ sub decoder ($;$$) {
 
                         $_->[0], $_->[1],
 
-                        $_->[0] . "i", $_->[1] . "i",
-                        $_->[0] . "u", $_->[1] . "u",
-
                         "\\cap\x09" . $_->[0], [ $_->[1], "\\cap " ],
                         "\\cap\x0A" . $_->[0], [ $_->[1], "\\cap " ],
                         "\\cap\x0D" . $_->[0], [ $_->[1], "\\cap " ],
                         "\\cap\x20" . $_->[0], [ $_->[1], "\\cap " ],
 
-                        "\\cap\x09" . $_->[0] . "i", $_->[1] . ucfirst "i",
-                        "\\cap\x0A" . $_->[0] . "i", $_->[1] . ucfirst "i",
-                        "\\cap\x0D" . $_->[0] . "i", $_->[1] . ucfirst "i",
-                        "\\cap\x20" . $_->[0] . "i", $_->[1] . ucfirst "i",
-
-                        "\\cap\x09" . $_->[0] . "u", $_->[1] . ucfirst "u",
-                        "\\cap\x0A" . $_->[0] . "u", $_->[1] . ucfirst "u",
-                        "\\cap\x0D" . $_->[0] . "u", $_->[1] . ucfirst "u",
-                        "\\cap\x20" . $_->[0] . "u", $_->[1] . ucfirst "u",
-
-                    } @minor
-                ),
-
-                (
-                    map {
-
-                        my $x = $_;
-
-                        map {
-
-                            $x->[0] . "i" . $_, [ $x->[1], "i" . $_ ],
-                            $x->[0] . "u" . $_, [ $x->[1], "u" . $_ ],
-
-                            "\\cap\x09" . $x->[0] . "i" . $_, [ $x->[1], "\\cap i" . $_ ],
-                            "\\cap\x0A" . $x->[0] . "i" . $_, [ $x->[1], "\\cap i" . $_ ],
-                            "\\cap\x0D" . $x->[0] . "i" . $_, [ $x->[1], "\\cap i" . $_ ],
-                            "\\cap\x20" . $x->[0] . "i" . $_, [ $x->[1], "\\cap i" . $_ ],
-
-                            "\\cap\x09" . $x->[0] . "u" . $_, [ $x->[1], "\\cap u" . $_ ],
-                            "\\cap\x0A" . $x->[0] . "u" . $_, [ $x->[1], "\\cap u" . $_ ],
-                            "\\cap\x0D" . $x->[0] . "u" . $_, [ $x->[1], "\\cap u" . $_ ],
-                            "\\cap\x20" . $x->[0] . "u" . $_, [ $x->[1], "\\cap u" . $_ ],
-
-                        }   "-", "\x09", "\x0A", "\x0D", "\x20"
-
                     } @minor
                 ),
 
@@ -540,10 +413,10 @@ sub decoder ($;$$) {
                 (
                     map {
 
-                        "\\cap\x09" . $_, [ "", "\\cap " ],
-                        "\\cap\x0A" . $_, [ "", "\\cap " ],
-                        "\\cap\x0D" . $_, [ "", "\\cap " ],
-                        "\\cap\x20" . $_, [ "", "\\cap " ],
+                        "\\cap\x09" . $_, [ '', "\\cap " ],
+                        "\\cap\x0A" . $_, [ '', "\\cap " ],
+                        "\\cap\x0D" . $_, [ '', "\\cap " ],
+                        "\\cap\x20" . $_, [ '', "\\cap " ],
 
                     } "\x09", "\x0A", "\x0D", "\x20"
                 ),
@@ -574,6 +447,11 @@ __END__
 Encode::Arabic::ArabTeX::ZDMG - ZDMG phonetic transcription of Arabic using the ArabTeX notation
 
 
+=head1 REVISION
+
+    $Revision: 143 $        $Date: 2006-11-15 02:16:57 +0100 (Wed, 15 Nov 2006) $
+
+
 =head1 SYNOPSIS
 
     use Encode::Arabic::ArabTeX::ZDMG;  # imports just like 'use Encode' would, plus extended options
@@ -607,29 +485,31 @@ inherits. The transformation rules are, however, quite different ;)
 =head1 SEE ALSO
 
 L<Encode::Arabic::ArabTeX|Encode::Arabic::ArabTeX>,
-L<Encode::Arabic|Encode::Arabic>, L<Encode::Mapper|Encode::Mapper>,
-L<Encode::Encoding|Encode::Encoding>, L<Encode|Encode>
+L<Encode::Arabic|Encode::Arabic>,
+L<Encode::Mapper|Encode::Mapper>,
+L<Encode::Encoding|Encode::Encoding>,
+L<Encode|Encode>
 
 ArabTeX system      L<ftp://ftp.informatik.uni-stuttgart.de/pub/arabtex/arabtex.htm>
 
 Klaus Lagally       L<http://www.informatik.uni-stuttgart.de/ifi/bs/people/lagall_e.htm>
 
-ArabTeX extensions  L<http://sourceforge.net/projects/encode-arabic/>
-
-ArabXeTeX           L<http://tug.ctan.org/info/?id=arabxetex>
-
 Encode Arabic: Exercise in Functional Parsing
     L<http://ufal.mff.cuni.cz/padt/online/2006/06/encode-arabic.html>
 
 
 =head1 AUTHOR
 
-Otakar Smrz C<< <otakar-smrz users.sf.net> >>, L<http://otakar-smrz.users.sf.net/>
+Otakar Smrz, L<http://ufal.mff.cuni.cz/~smrz/>
+
+    eval { 'E<lt>' . ( join '.', qw 'otakar smrz' ) . "\x40" . ( join '.', qw 'mff cuni cz' ) . 'E<gt>' }
+
+Perl is also designed to make the easy jobs not that easy ;)
 
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2003-2010 Otakar Smrz
+Copyright 2003-2006 by Otakar Smrz
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
